@@ -111,7 +111,7 @@ class EPUBArticle:
             image_path = join("..", IMAGES, image_name)
             img["src"] = image_path
 
-        return soup.decode(pretty_print=True)
+        return soup.decode()
 
     def download_image(self, url: str) -> str:
         """
@@ -119,6 +119,8 @@ class EPUBArticle:
         """
         logger.debug(f"Downloading image {url}...")
         image_name = images.get_image_filename(url)
+        if len(image_name) > 150:
+            image_name = image_name[:150]
         image_path = join(self.images_path, image_name)
         images.download_image(url, image_path)
         return image_name
